from typing import Optional
from pydantic import BaseModel
from datetime import datetime


# Shared properties
class ItemBase(BaseModel):
    title: str
    description: Optional[str] = None
    is_active: Optional[bool] = True


# Properties to receive on item creation
class ItemCreate(ItemBase):
    pass


# Properties to receive on item update
class ItemUpdate(ItemBase):
    title: Optional[str] = None
    is_active: Optional[bool] = None


# Properties shared by models stored in DB
class ItemInDBBase(ItemBase):
    id: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True


# Properties to return to client
class Item(ItemInDBBase):
    pass